"use strict";
// Copyright 2017-2018 Stratumn SAS. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var b64 = __importStar(require("base64-js"));
var evidence_1 = require("../evidence");
var link_builder_1 = require("../link_builder");
var segment_1 = require("../segment");
/**
 * Test a segment with evidences.
 */
var EvidencesTest = /** @class */ (function () {
    function EvidencesTest() {
    }
    EvidencesTest.prototype.id = function () {
        return EvidencesTest.id;
    };
    EvidencesTest.prototype.generate = function () {
        var segment = new link_builder_1.LinkBuilder("test_process", "test_map")
            .build()
            .segmentify();
        segment.addEvidence(new evidence_1.Evidence("0.1.0", "bitcoin", "testnet", Uint8Array.from([42])));
        segment.addEvidence(new evidence_1.Evidence("1.0.3", "ethereum", "mainnet", Uint8Array.from([24])));
        return b64.fromByteArray(segment.serialize());
    };
    EvidencesTest.prototype.validate = function (encodedSegment) {
        var segment = segment_1.deserialize(b64.toByteArray(encodedSegment));
        segment.validate();
        if (segment.evidences().length !== 2) {
            throw new Error("Invalid evidences count: " + segment.evidences().length);
        }
        var btc = segment.getEvidence("bitcoin", "testnet");
        if (!btc) {
            throw new Error("Missing bitcoin evidence");
        }
        if (btc.version !== "0.1.0" ||
            btc.backend !== "bitcoin" ||
            btc.provider !== "testnet" ||
            btc.proof[0] !== 42) {
            throw new Error("Invalid bitcoin evidence: " + JSON.stringify(btc));
        }
        var eth = segment.getEvidence("ethereum", "mainnet");
        if (!eth) {
            throw new Error("Missing ethereum evidence");
        }
        if (eth.version !== "1.0.3" ||
            eth.backend !== "ethereum" ||
            eth.provider !== "mainnet" ||
            eth.proof[0] !== 24) {
            throw new Error("Invalid ethereum evidence: " + JSON.stringify(eth));
        }
    };
    EvidencesTest.id = "segment-evidences";
    return EvidencesTest;
}());
exports.EvidencesTest = EvidencesTest;
//# sourceMappingURL=evidences.js.map