"use strict";
// Copyright 2017-2018 Stratumn SAS. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var b64 = __importStar(require("base64-js"));
var link_builder_1 = require("../link_builder");
var ref_1 = require("../ref");
var segment_1 = require("../segment");
/**
 * Test a segment with references.
 */
var ReferencesTest = /** @class */ (function () {
    function ReferencesTest() {
    }
    ReferencesTest.prototype.id = function () {
        return ReferencesTest.id;
    };
    ReferencesTest.prototype.generate = function () {
        var segment = new link_builder_1.LinkBuilder("test_process", "test_map")
            .withRefs([
            new ref_1.LinkReference(Uint8Array.from([42]), "p1"),
            new ref_1.LinkReference(Uint8Array.from([24]), "p2")
        ])
            .build()
            .segmentify();
        return b64.fromByteArray(segment.serialize());
    };
    ReferencesTest.prototype.validate = function (encodedSegment) {
        var segment = segment_1.deserialize(b64.toByteArray(encodedSegment));
        segment.validate();
        var link = segment.link();
        var refs = link.refs();
        if (refs.length !== 2) {
            throw new Error("Invalid references count: " + refs.length);
        }
        if (refs[0].process !== "p1") {
            throw new Error("Invalid first reference process: " + refs[0].process);
        }
        if (refs[0].linkHash[0] !== 42) {
            throw new Error("Invalid first reference link hash: " + refs[0].linkHash);
        }
        if (refs[1].process !== "p2") {
            throw new Error("Invalid second reference process: " + refs[1].process);
        }
        if (refs[1].linkHash[0] !== 24) {
            throw new Error("Invalid second reference link hash: " + refs[1].linkHash);
        }
    };
    ReferencesTest.id = "segment-references";
    return ReferencesTest;
}());
exports.ReferencesTest = ReferencesTest;
//# sourceMappingURL=references.js.map