"use strict";
// Copyright 2017-2018 Stratumn SAS. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var js_crypto_1 = require("@stratumn/js-crypto");
var b64 = __importStar(require("base64-js"));
var link_builder_1 = require("../link_builder");
var segment_1 = require("../segment");
/**
 * Test a segment with signatures.
 */
var SignaturesTest = /** @class */ (function () {
    function SignaturesTest() {
    }
    SignaturesTest.prototype.id = function () {
        return SignaturesTest.id;
    };
    SignaturesTest.prototype.generate = function () {
        var ed25519Key = new js_crypto_1.sig.SigningPrivateKey({
            algo: js_crypto_1.sig.SIGNING_ALGO_ED25519.name
        });
        var rsaKey = new js_crypto_1.sig.SigningPrivateKey({
            algo: js_crypto_1.sig.SIGNING_ALGO_RSA.name
        });
        var link = new link_builder_1.LinkBuilder("test_process", "test_map")
            .withAction("ʙᴀᴛᴍᴀɴ")
            .build();
        link.sign(ed25519Key.export(), "");
        link.sign(rsaKey.export(), "[version,meta.mapId]");
        var segment = link.segmentify();
        return b64.fromByteArray(segment.serialize());
    };
    SignaturesTest.prototype.validate = function (encodedSegment) {
        var segment = segment_1.deserialize(b64.toByteArray(encodedSegment));
        segment.validate();
        var signatures = segment.link().signatures();
        if (signatures.length !== 2) {
            throw new Error("Invalid number of signatures: " + signatures.length);
        }
        signatures[0].validate(segment.link());
        signatures[1].validate(segment.link());
        if (signatures[0].payloadPath() !== "[version,data,meta]") {
            throw new Error("Invalid first signature payload path: " + signatures[0].payloadPath());
        }
        if (signatures[1].payloadPath() !== "[version,meta.mapId]") {
            throw new Error("Invalid second signature payload path: " + signatures[1].payloadPath());
        }
    };
    SignaturesTest.id = "segment-signatures";
    return SignaturesTest;
}());
exports.SignaturesTest = SignaturesTest;
//# sourceMappingURL=signatures.js.map